=== modified file 'juju-ci-tools-common'
--- juju-ci-tools-common	2016-06-07 17:52:50 +0000
+++ juju-ci-tools-common	2016-06-20 19:42:23 +0000
@@ -4,7 +4,7 @@
 
 Package: juju-ci-tools.common
 Version: 0.1.0-0
-Depends: s3cmd, euca2ools, uvtool-libvirt, uvtool, simplestreams, distro-info-data, python-tz, python-mock, python-jenkins, python-launchpadlib, python-yaml, python-boto, python-novaclient, python-pexpect, python-winrm, python-coverage, python-pip
+Depends: s3cmd, euca2ools, uvtool-libvirt, uvtool, simplestreams, distro-info-data, python-tz, python-mock, python-jenkins, python-launchpadlib, python-yaml, python-boto, python-novaclient, python-pexpect, python-coverage, python-pip, python-fixtures
 Architecture: all
 Description: juju-ci-tools-common
  A metapackage providing the dependencies for juju-reports

=== modified file 'mac-win-requirements.txt'
--- mac-win-requirements.txt	2016-06-20 13:53:57 +0000
+++ mac-win-requirements.txt	2016-06-20 19:42:23 +0000
@@ -27,6 +27,7 @@
 fixtures>=1.3.1
 httplib2>=0.9.1
 iso8601>=0.1.10
+isodate>=0.5.1
 keyring>=5.3
 launchpadlib>=1.10.2
 lazr.authentication>=0.1.3

=== added file 'obsolete-requirements.txt'
--- obsolete-requirements.txt	1970-01-01 00:00:00 +0000
+++ obsolete-requirements.txt	2016-06-20 19:42:23 +0000
@@ -0,0 +1,1 @@
+azure (0.8.0)

=== modified file 'pipdeps.py'
--- pipdeps.py	2016-06-17 21:43:03 +0000
+++ pipdeps.py	2016-06-20 19:42:23 +0000
@@ -18,6 +18,8 @@
 PREFIX = "juju-ci-tools/"
 REQUIREMENTS = os.path.join(os.path.realpath(os.path.dirname(__file__)),
                             "requirements.txt")
+OBSOLETE = os.path.join(os.path.realpath(os.path.dirname(__file__)),
+                        "obsolete-requirements.txt")
 
 
 def s3_anon():
@@ -48,12 +50,40 @@
     subprocess.check_call(cmd)
 
 
+def run_pip_uninstall(obsolete_requirements, verbose=False):
+    """Run pip uninstall for each package version in obsolete_requirements.
+
+    pip uninstall the package without regard to its version. In most cases,
+    calling install install with a new package version implicitly upgrades.
+    There are only a few package version that cannot by upgraded, they must
+    be removed before install. This function uninstalls packages only when
+    their version matches the obsolete.
+
+    The obsolete_requirements entries must match the output of pip list. eg:
+        azure (0.8.0)
+        bibbel (1.2.3)
+    """
+    pip_cmd = ['pip']
+    if not verbose:
+        pip_cmd.append('-q')
+    list_cmd = pip_cmd + ['list']
+    installed_packages = set(subprocess.check_output(list_cmd).splitlines())
+    with open(obsolete_requirements, 'r') as o_file:
+        obsolete_packages = o_file.read().splitlines()
+    removable = installed_packages.intersection(obsolete_packages)
+    for package_version in removable:
+        package, version = package_version.split()
+        uninstall_cmd = pip_cmd + ['uninstall', package]
+        subprocess.check_call(uninstall_cmd)
+
+
 def command_install(bucket, requirements, verbose=False):
     with utility.temp_dir() as archives_dir:
         for key in bucket.list(prefix=PREFIX):
             archive = key.name[len(PREFIX):]
             key.get_contents_to_filename(os.path.join(archives_dir, archive))
         archives_url = "file://" + archives_dir
+        run_pip_uninstall(OBSOLETE, verbose=verbose)
         run_pip_install(["--user", "--no-index", "--find-links", archives_url],
                         requirements, verbose=verbose)
 

=== modified file 'requirements.txt'
--- requirements.txt	2016-06-20 13:53:57 +0000
+++ requirements.txt	2016-06-20 19:42:23 +0000
@@ -1,3 +1,28 @@
 azure==2.0.0rc3
+azure-batch==0.30.0rc3
+azure-common==1.1.3
+azure-graphrbac==0.30.0rc3
+azure-mgmt==0.30.0rc3
+azure-mgmt-authorization==0.30.0rc3
+azure-mgmt-batch==0.30.0rc3
+azure-mgmt-cdn==0.30.0rc3
+azure-mgmt-compute==0.30.0rc3
+azure-mgmt-logic==0.30.0rc3
+azure-mgmt-network==0.30.0rc3
+azure-mgmt-notificationhubs==0.30.0rc3
+azure-mgmt-nspkg==1.0.0
+azure-mgmt-redis==0.30.0rc3
+azure-mgmt-resource==0.30.0rc3
+azure-mgmt-scheduler==0.30.0rc3
+azure-mgmt-storage==0.30.0rc3
+azure-mgmt-web==0.30.0rc3
+azure-nspkg==1.0.0
+azure-servicebus==0.20.1
+azure-servicemanagement-legacy==0.20.3
+azure-storage>=0.31.0
+isodate>=0.5.1
+msgpack-python>=0.4.6
+msrestazure>=0.3.0
 pywinrm==0.0.3
 pexpect>=2.4
+xmltodict>=0.9.2

=== modified file 'tests/test_pipdeps.py'
--- tests/test_pipdeps.py	2016-06-17 21:43:03 +0000
+++ tests/test_pipdeps.py	2016-06-20 19:42:23 +0000
@@ -81,3 +81,20 @@
                 ["--download", "/tmp/pip"], self.req_path, verbose=True)
         cc_mock.assert_called_once_with([
             "pip", "install", "-r", self.req_path, "--download", "/tmp/pip"])
+
+
+class TestRunPipUninstall(unittest.TestCase):
+
+    def test_run_pip_uninstall(self):
+        with utility.temp_dir() as base:
+            obsolete = os.path.join(base, 'obsolete.txt')
+            with open(obsolete, 'w') as o_file:
+                o_file.write('foo (9.7.6)\nazure (0.8.0)')
+            list_output = 'azure (0.8.0)\nbar (1.2.3)'
+            with mock.patch("subprocess.check_output", autospec=True,
+                            return_value=list_output) as co_mock:
+                with mock.patch("subprocess.check_call",
+                                autospec=True) as cc_mock:
+                    pipdeps.run_pip_uninstall(obsolete, verbose=False)
+        co_mock.assert_called_once_with(['pip', '-q', 'list'])
+        cc_mock.assert_called_once_with(['pip', '-q', 'uninstall', 'azure'])

